@@ -73,6 +73,27 @@ class Just(t.Generic[_T]):
         """
         return chainer(self.value)
 
+    def chain_nullable(
+        self, chainer: t.Callable[[_T], t.Optional['_TT']]
+    ) -> 'Maybe[_TT]':
+        """Similar to ``chain`` but for a function that returns an options.
+
+        >>> from ._nothing import Nothing
+        >>> Just(5).chain_nullable(lambda el: el * el)
+        Just(25)
+        >>> Just(5).chain_nullable(lambda _: None)
+        Nothing
+        >>> Just(5).chain_nullable(lambda el: Just(el * el))
+        Just(Just(25))
+        >>> Nothing.chain_nullable(lambda el: el * el)
+        Nothing
+        >>> Nothing.chain_nullable(lambda _: None)
+        Nothing
+        """
+        # pylint: disable=import-outside-toplevel
+        from .utils import from_nullable
+        return from_nullable(chainer(self.value))
+
     def __repr__(self) -> str:
         return f'Just({self.value!r})'
 
@@ -241,6 +262,14 @@ class Just(t.Generic[_T]):
         """
         return self.value == val
 
+    def ne(  # pylint: disable=invalid-name
+        self: 'Just[_Y]',
+        val: _Y,
+    ) -> bool:
+        """Check if a value of a ``Just`` is not equal to the given value.
+        """
+        return self.value != val
+
     def lt(  # pylint: disable=invalid-name
         self: 'Just[_SupportsLessThan[_T]]',
         val: _SupportsLessThan[_T],
