@@ -38,6 +38,11 @@ class _Nothing(t.Generic[_T]):
     ) -> _Y:
         return default
 
+    def chain_nullable(
+        self, _chainer: t.Callable[[_T], t.Optional['_TT']]
+    ) -> '_Nothing[_TT]':
+        return Nothing
+
     def chain(
         self, _chainer: t.Callable[[_T], 'Maybe[_TT]']
     ) -> '_Nothing[_TT]':
@@ -120,6 +125,8 @@ class _Nothing(t.Generic[_T]):
     ) -> Literal[False]:
         return False
 
+    ne = eq  # pylint: disable=invalid-name
+
     def lt(  # pylint: disable=invalid-name
         self: '_Nothing[_SupportsLessThan[_T]]',
         val: _SupportsLessThan[_T],  # pylint: disable=unused-argument
