@@ -15,6 +15,7 @@ import datetime
 import textwrap
 import warnings
 import functools
+import threading
 import contextlib
 import collections
 import dataclasses
@@ -108,11 +109,11 @@ class _SwaggerFunc:
     query_parser: t.Optional['BaseFixedMapping']
 
 
-_SWAGGER_FUNCS: t.Dict[str, _SwaggerFunc] = {}
+_SWAGGER_FUNCS: t.Dict[str, t.Dict[t.Optional[str], _SwaggerFunc]] = {}
 
 
 def swaggerize(
-    operation_name: str,
+    operation_name: t.Union[str, t.Mapping[str, str]],
     *,
     no_data: bool = False,
 ) -> t.Callable[[_CallableT], _CallableT]:
@@ -151,9 +152,17 @@ def swaggerize(
                 from_query=True,
             )
 
-        _SWAGGER_FUNCS[func.__name__] = _SwaggerFunc(
-            operation_name, no_data, func, query_parser=query_parser
-        )
+        func_dict = _SWAGGER_FUNCS.setdefault(func.__name__, {})
+        if isinstance(operation_name, str):
+            func_dict[None] = _SwaggerFunc(
+                operation_name, no_data, func, query_parser=query_parser
+            )
+        else:
+            for method, name in operation_name.items():
+                func_dict[method] = _SwaggerFunc(
+                    name, no_data, func, query_parser=query_parser
+                )
+
         if query_parser is None:
             return func
 
@@ -711,6 +720,8 @@ class Lazy(t.Generic[_T], Parser[_T]):
     The method ``make_parser`` will be executed when you first try to parse
     something. It will only be executed once.
     """
+    _LOCK = threading.RLock()
+
     if _USE_SLOTS:
         __slots__ = ('_parser', '_make_parser')
 
@@ -724,7 +735,9 @@ class Lazy(t.Generic[_T], Parser[_T]):
         """The parser that this lazy uses.
         """
         if self._parser is None:
-            self._parser = self._make_parser()
+            with self._LOCK:
+                if self._parser is None:
+                    self._parser = self._make_parser()
         return self._parser
 
     def describe(self) -> str:
@@ -1712,7 +1725,9 @@ class RichValue:
 
     Password = _Password()
 
-    class _TimeDelta(Transform[datetime.timedelta, t.Union[str, float]]):
+    class TimeDeltaFactory(Transform[datetime.timedelta, t.Union[str, float]]):
+        """Factory to create a ISO timedelta parser.
+        """
         # The regex below are copied from Pydantic
         _ISO8601_DURATION_RE = re.compile(
             r'^(?P<sign>[-+]?)'
@@ -1726,9 +1741,9 @@ class RichValue:
             r'$'
         )
 
-        def __init__(self) -> None:
+        def __init__(self, parser: Parser[t.Union[str, float]]) -> None:
             super().__init__(
-                SimpleValue.str | SimpleValue.float,
+                parser,
                 self.__to_timedelta,
                 'TimeDelta',
             )
@@ -1769,7 +1784,16 @@ class RichValue:
                 microseconds=float(groups.get('microseconds', 0)),
             )
 
-    TimeDelta = _TimeDelta()
+    TimeDelta = TimeDeltaFactory(SimpleValue.str | SimpleValue.float)
+
+    class _StringWithoutNullByte(_SimpleValue[str]):
+        def __init__(self) -> None:
+            super().__init__(str)
+
+        def try_parse(self, value: object) -> str:
+            return super().try_parse(value).replace('\0', '')
+
+    StringWithoutNullByte = _StringWithoutNullByte()
 
 
 class _BoolQueryParam(Transform[bool, str]):
