@@ -72,7 +72,9 @@ class CourseService(Generic[_ClientT]):
             return JsonResponseParser(
                 rqa.List(ParserFor.make(ExtendedCourse))
             ).try_parse(response)
-        raise get_error(response, [((400, 409, 401, 403, "5XX"), BaseError)])
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
 
     def create(
         self: "CourseService[AuthenticatedClient]",
@@ -110,59 +112,9 @@ class CourseService(Generic[_ClientT]):
             return JsonResponseParser(
                 ParserFor.make(ExtendedCourse)
             ).try_parse(response)
-        raise get_error(response, [((400, 409, 401, 403, "5XX"), BaseError)])
-
-    def get_submissions_by_user(
-        self: "CourseService[AuthenticatedClient]",
-        *,
-        course_id: "int",
-        user_id: "int",
-        latest_only: "bool" = False,
-        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
-    ) -> "Mapping[str, Sequence[ExtendedWork]]":
-        """Get all submissions by the given user in this course.
-
-        :param course_id: The id of the course from which you want to get the
-            submissions.
-        :param user_id: The id of the user of which you want to get the
-            submissions.
-        :param latest_only: Only get the latest submission of a user. Please
-            use this option if at all possible, as students have a tendency to
-            submit many attempts and that can make this route quite slow.
-        :param extra_parameters: The extra query parameters you might want to
-            add. By default no extra query parameters are added.
-
-        :returns: A mapping between assignment id and the submissions done in
-                  that assignment by the given user. If the `latest_only` query
-                  parameter was used the value will still be an array of
-                  submissions, but the length will always be one. If the user
-                  didn't submit for an assignment the value might be empty or
-                  the id of the assignment will be missing from the returned
-                  object.
-        """
-        from typing import Dict, Mapping, Sequence
-
-        from ..models.base_error import BaseError
-        from ..models.extended_work import ExtendedWork
-        from ..parsers import JsonResponseParser, ParserFor
-
-        url = "/api/v1/courses/{courseId}/users/{userId}/submissions/".format(
-            courseId=course_id, userId=user_id
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
         )
-        params: "Dict[str, Any]" = {
-            **(extra_parameters or {}),
-            "latest_only": to_dict(latest_only),
-        }
-
-        with self.__client as client:
-            response = client.http.get(url=url, params=params)
-        log_warnings(response)
-
-        if response_code_matches(response.status_code, 200):
-            return JsonResponseParser(
-                rqa.LookupMapping(rqa.List(ParserFor.make(ExtendedWork)))
-            ).try_parse(response)
-        raise get_error(response, [((400, 409, 401, 403, "5XX"), BaseError)])
 
     def put_enroll_link(
         self: "CourseService[AuthenticatedClient]",
@@ -206,77 +158,9 @@ class CourseService(Generic[_ClientT]):
             return JsonResponseParser(
                 ParserFor.make(CourseRegistrationLink)
             ).try_parse(response)
-        raise get_error(response, [((400, 409, 401, 403, "5XX"), BaseError)])
-
-    def get_group_sets(
-        self: "CourseService[AuthenticatedClient]",
-        *,
-        course_id: "int",
-        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
-    ) -> "Sequence[GroupSet]":
-        """Get the all the group sets of a given course.
-
-        :param course_id: The id of the course of which the group sets should
-            be retrieved.
-        :param extra_parameters: The extra query parameters you might want to
-            add. By default no extra query parameters are added.
-
-        :returns: A list of group sets.
-        """
-        from typing import Sequence
-
-        from ..models.base_error import BaseError
-        from ..models.group_set import GroupSet
-        from ..parsers import JsonResponseParser, ParserFor
-
-        url = "/api/v1/courses/{courseId}/group_sets/".format(
-            courseId=course_id
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
         )
-        params = extra_parameters or {}
-
-        with self.__client as client:
-            response = client.http.get(url=url, params=params)
-        log_warnings(response)
-
-        if response_code_matches(response.status_code, 200):
-            return JsonResponseParser(
-                rqa.List(ParserFor.make(GroupSet))
-            ).try_parse(response)
-        raise get_error(response, [((400, 409, 401, 403, "5XX"), BaseError)])
-
-    def get_snippets(
-        self: "CourseService[AuthenticatedClient]",
-        *,
-        course_id: "int",
-        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
-    ) -> "Sequence[CourseSnippet]":
-        """Get all snippets of the given course.
-
-        :param course_id: The id of the course from which you want to get the
-            snippets.
-        :param extra_parameters: The extra query parameters you might want to
-            add. By default no extra query parameters are added.
-
-        :returns: An array containing all snippets for the given course.
-        """
-        from typing import Sequence
-
-        from ..models.base_error import BaseError
-        from ..models.course_snippet import CourseSnippet
-        from ..parsers import JsonResponseParser, ParserFor
-
-        url = "/api/v1/courses/{courseId}/snippets/".format(courseId=course_id)
-        params = extra_parameters or {}
-
-        with self.__client as client:
-            response = client.http.get(url=url, params=params)
-        log_warnings(response)
-
-        if response_code_matches(response.status_code, 200):
-            return JsonResponseParser(
-                rqa.List(ParserFor.make(CourseSnippet))
-            ).try_parse(response)
-        raise get_error(response, [((400, 409, 401, 403, "5XX"), BaseError)])
 
     def delete_role(
         self: "CourseService[AuthenticatedClient]",
@@ -308,7 +192,9 @@ class CourseService(Generic[_ClientT]):
 
         if response_code_matches(response.status_code, 204):
             return ConstantlyParser(None).try_parse(response)
-        raise get_error(response, [((400, 409, 401, 403, "5XX"), BaseError)])
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
 
     def get_all_users(
         self: "CourseService[AuthenticatedClient]",
@@ -347,7 +233,9 @@ class CourseService(Generic[_ClientT]):
                     rqa.List(ParserFor.make(UserCourse)),
                 )
             ).try_parse(response)
-        raise get_error(response, [((400, 409, 401, 403, "5XX"), BaseError)])
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
 
     def change_user_role(
         self: "CourseService[AuthenticatedClient]",
@@ -399,45 +287,9 @@ class CourseService(Generic[_ClientT]):
             )
         if response_code_matches(response.status_code, 204):
             return ConstantlyParser(None).try_parse(response)
-        raise get_error(response, [((400, 409, 401, 403, "5XX"), BaseError)])
-
-    def email_users(
-        self: "CourseService[AuthenticatedClient]",
-        json_body: Union[dict, list, "EmailUsersCourseData"],
-        *,
-        course_id: "int",
-        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
-    ) -> "Job":
-        """Sent the authors in this course an email.
-
-        :param json_body: The body of the request. See
-            :model:`.EmailUsersCourseData` for information about the possible
-            fields. You can provide this data as a
-            :model:`.EmailUsersCourseData` or as a dictionary.
-        :param course_id: The id of the course in which you want to send the
-            emails.
-        :param extra_parameters: The extra query parameters you might want to
-            add. By default no extra query parameters are added.
-
-        :returns: A task result that will send these emails.
-        """
-        from ..models.base_error import BaseError
-        from ..models.email_users_course_data import EmailUsersCourseData
-        from ..models.job import Job
-        from ..parsers import JsonResponseParser, ParserFor, make_union
-
-        url = "/api/v1/courses/{courseId}/email".format(courseId=course_id)
-        params = extra_parameters or {}
-
-        with self.__client as client:
-            response = client.http.post(
-                url=url, json=to_dict(json_body), params=params
-            )
-        log_warnings(response)
-
-        if response_code_matches(response.status_code, 200):
-            return JsonResponseParser(ParserFor.make(Job)).try_parse(response)
-        raise get_error(response, [((400, 409, 401, 403, "5XX"), BaseError)])
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
 
     def get(
         self: "CourseService[AuthenticatedClient]",
@@ -468,7 +320,9 @@ class CourseService(Generic[_ClientT]):
             return JsonResponseParser(
                 ParserFor.make(ExtendedCourse)
             ).try_parse(response)
-        raise get_error(response, [((400, 409, 401, 403, "5XX"), BaseError)])
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
 
     def patch(
         self: "CourseService[AuthenticatedClient]",
@@ -507,4 +361,174 @@ class CourseService(Generic[_ClientT]):
             return JsonResponseParser(
                 ParserFor.make(ExtendedCourse)
             ).try_parse(response)
-        raise get_error(response, [((400, 409, 401, 403, "5XX"), BaseError)])
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
+
+    def get_snippets(
+        self: "CourseService[AuthenticatedClient]",
+        *,
+        course_id: "int",
+        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+    ) -> "Sequence[CourseSnippet]":
+        """Get all snippets of the given course.
+
+        :param course_id: The id of the course from which you want to get the
+            snippets.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: An array containing all snippets for the given course.
+        """
+        from typing import Sequence
+
+        from ..models.base_error import BaseError
+        from ..models.course_snippet import CourseSnippet
+        from ..parsers import JsonResponseParser, ParserFor
+
+        url = "/api/v1/courses/{courseId}/snippets/".format(courseId=course_id)
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            response = client.http.get(url=url, params=params)
+        log_warnings(response)
+
+        if response_code_matches(response.status_code, 200):
+            return JsonResponseParser(
+                rqa.List(ParserFor.make(CourseSnippet))
+            ).try_parse(response)
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
+
+    def get_group_sets(
+        self: "CourseService[AuthenticatedClient]",
+        *,
+        course_id: "int",
+        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+    ) -> "Sequence[GroupSet]":
+        """Get the all the group sets of a given course.
+
+        :param course_id: The id of the course of which the group sets should
+            be retrieved.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: A list of group sets.
+        """
+        from typing import Sequence
+
+        from ..models.base_error import BaseError
+        from ..models.group_set import GroupSet
+        from ..parsers import JsonResponseParser, ParserFor
+
+        url = "/api/v1/courses/{courseId}/group_sets/".format(
+            courseId=course_id
+        )
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            response = client.http.get(url=url, params=params)
+        log_warnings(response)
+
+        if response_code_matches(response.status_code, 200):
+            return JsonResponseParser(
+                rqa.List(ParserFor.make(GroupSet))
+            ).try_parse(response)
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
+
+    def get_submissions_by_user(
+        self: "CourseService[AuthenticatedClient]",
+        *,
+        course_id: "int",
+        user_id: "int",
+        latest_only: "bool" = False,
+        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+    ) -> "Mapping[str, Sequence[ExtendedWork]]":
+        """Get all submissions by the given user in this course.
+
+        :param course_id: The id of the course from which you want to get the
+            submissions.
+        :param user_id: The id of the user of which you want to get the
+            submissions.
+        :param latest_only: Only get the latest submission of a user. Please
+            use this option if at all possible, as students have a tendency to
+            submit many attempts and that can make this route quite slow.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: A mapping between assignment id and the submissions done in
+                  that assignment by the given user. If the `latest_only` query
+                  parameter was used the value will still be an array of
+                  submissions, but the length will always be one. If the user
+                  didn't submit for an assignment the value might be empty or
+                  the id of the assignment will be missing from the returned
+                  object.
+        """
+        from typing import Dict, Mapping, Sequence
+
+        from ..models.base_error import BaseError
+        from ..models.extended_work import ExtendedWork
+        from ..parsers import JsonResponseParser, ParserFor
+
+        url = "/api/v1/courses/{courseId}/users/{userId}/submissions/".format(
+            courseId=course_id, userId=user_id
+        )
+        params: "Dict[str, Any]" = {
+            **(extra_parameters or {}),
+            "latest_only": to_dict(latest_only),
+        }
+
+        with self.__client as client:
+            response = client.http.get(url=url, params=params)
+        log_warnings(response)
+
+        if response_code_matches(response.status_code, 200):
+            return JsonResponseParser(
+                rqa.LookupMapping(rqa.List(ParserFor.make(ExtendedWork)))
+            ).try_parse(response)
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
+
+    def email_users(
+        self: "CourseService[AuthenticatedClient]",
+        json_body: Union[dict, list, "EmailUsersCourseData"],
+        *,
+        course_id: "int",
+        extra_parameters: Mapping[str, Union[str, bool, int, float]] = None,
+    ) -> "Job":
+        """Sent the authors in this course an email.
+
+        :param json_body: The body of the request. See
+            :model:`.EmailUsersCourseData` for information about the possible
+            fields. You can provide this data as a
+            :model:`.EmailUsersCourseData` or as a dictionary.
+        :param course_id: The id of the course in which you want to send the
+            emails.
+        :param extra_parameters: The extra query parameters you might want to
+            add. By default no extra query parameters are added.
+
+        :returns: A task result that will send these emails.
+        """
+        from ..models.base_error import BaseError
+        from ..models.email_users_course_data import EmailUsersCourseData
+        from ..models.job import Job
+        from ..parsers import JsonResponseParser, ParserFor, make_union
+
+        url = "/api/v1/courses/{courseId}/email".format(courseId=course_id)
+        params = extra_parameters or {}
+
+        with self.__client as client:
+            response = client.http.post(
+                url=url, json=to_dict(json_body), params=params
+            )
+        log_warnings(response)
+
+        if response_code_matches(response.status_code, 200):
+            return JsonResponseParser(ParserFor.make(Job)).try_parse(response)
+        raise get_error(
+            response, [((400, 409, 401, 403, 404, "5XX"), BaseError)]
+        )
