@@ -33,6 +33,7 @@ if t.TYPE_CHECKING:
     from codegrade._api.site_settings import (
         SiteSettingsService as _SiteSettingsService,
     )
+    from codegrade._api.snippet import SnippetService as _SnippetService
     from codegrade._api.submission import (
         SubmissionService as _SubmissionService,
     )
@@ -50,21 +51,22 @@ class _BaseClient:
     """A base class for keeping track of data related to the API."""
 
     __slots__ = (
-        "__user_setting",
-        "__lti",
-        "__site_settings",
-        "__assignment",
-        "__auto_test",
-        "__course",
-        "__tenant",
         "__about",
-        "__user",
-        "__task_result",
-        "__comment",
-        "__submission",
+        "__assignment",
+        "__course",
         "__group",
-        "__login_link",
+        "__user",
+        "__auto_test",
+        "__lti",
+        "__tenant",
+        "__submission",
         "__file",
+        "__login_link",
+        "__user_setting",
+        "__comment",
+        "__site_settings",
+        "__snippet",
+        "__task_result",
         "__open_level",
     )
 
@@ -72,31 +74,32 @@ class _BaseClient:
         # Open level makes it possible to efficiently nest the context manager.
         self.__open_level = 0
 
-        self.__user_setting: t.Optional[
-            "_UserSettingService[_BaseClientT]"
-        ] = None
-        self.__lti: t.Optional["_LTIService[_BaseClientT]"] = None
-        self.__site_settings: t.Optional[
-            "_SiteSettingsService[_BaseClientT]"
-        ] = None
+        self.__about: t.Optional["_AboutService[_BaseClientT]"] = None
         self.__assignment: t.Optional[
             "_AssignmentService[_BaseClientT]"
         ] = None
-        self.__auto_test: t.Optional["_AutoTestService[_BaseClientT]"] = None
         self.__course: t.Optional["_CourseService[_BaseClientT]"] = None
-        self.__tenant: t.Optional["_TenantService[_BaseClientT]"] = None
-        self.__about: t.Optional["_AboutService[_BaseClientT]"] = None
+        self.__group: t.Optional["_GroupService[_BaseClientT]"] = None
         self.__user: t.Optional["_UserService[_BaseClientT]"] = None
-        self.__task_result: t.Optional[
-            "_TaskResultService[_BaseClientT]"
-        ] = None
-        self.__comment: t.Optional["_CommentService[_BaseClientT]"] = None
+        self.__auto_test: t.Optional["_AutoTestService[_BaseClientT]"] = None
+        self.__lti: t.Optional["_LTIService[_BaseClientT]"] = None
+        self.__tenant: t.Optional["_TenantService[_BaseClientT]"] = None
         self.__submission: t.Optional[
             "_SubmissionService[_BaseClientT]"
         ] = None
-        self.__group: t.Optional["_GroupService[_BaseClientT]"] = None
-        self.__login_link: t.Optional["_LoginLinkService[_BaseClientT]"] = None
         self.__file: t.Optional["_FileService[_BaseClientT]"] = None
+        self.__login_link: t.Optional["_LoginLinkService[_BaseClientT]"] = None
+        self.__user_setting: t.Optional[
+            "_UserSettingService[_BaseClientT]"
+        ] = None
+        self.__comment: t.Optional["_CommentService[_BaseClientT]"] = None
+        self.__site_settings: t.Optional[
+            "_SiteSettingsService[_BaseClientT]"
+        ] = None
+        self.__snippet: t.Optional["_SnippetService[_BaseClientT]"] = None
+        self.__task_result: t.Optional[
+            "_TaskResultService[_BaseClientT]"
+        ] = None
 
     def _get_headers(self) -> t.Mapping[str, str]:
         """Get headers to be used in all endpoints"""
@@ -123,6 +126,94 @@ class _BaseClient:
         if self.__open_level == 0:
             self.http.__exit__(exc_type, exc_value, traceback)
 
+    @property
+    def about(self: _BaseClientT) -> "_AboutService[_BaseClientT]":
+        if self.__about is None:
+            import codegrade._api.about as m
+
+            self.__about = m.AboutService(self)
+        return self.__about
+
+    @property
+    def assignment(self: _BaseClientT) -> "_AssignmentService[_BaseClientT]":
+        if self.__assignment is None:
+            import codegrade._api.assignment as m
+
+            self.__assignment = m.AssignmentService(self)
+        return self.__assignment
+
+    @property
+    def course(self: _BaseClientT) -> "_CourseService[_BaseClientT]":
+        if self.__course is None:
+            import codegrade._api.course as m
+
+            self.__course = m.CourseService(self)
+        return self.__course
+
+    @property
+    def group(self: _BaseClientT) -> "_GroupService[_BaseClientT]":
+        if self.__group is None:
+            import codegrade._api.group as m
+
+            self.__group = m.GroupService(self)
+        return self.__group
+
+    @property
+    def user(self: _BaseClientT) -> "_UserService[_BaseClientT]":
+        if self.__user is None:
+            import codegrade._api.user as m
+
+            self.__user = m.UserService(self)
+        return self.__user
+
+    @property
+    def auto_test(self: _BaseClientT) -> "_AutoTestService[_BaseClientT]":
+        if self.__auto_test is None:
+            import codegrade._api.auto_test as m
+
+            self.__auto_test = m.AutoTestService(self)
+        return self.__auto_test
+
+    @property
+    def lti(self: _BaseClientT) -> "_LTIService[_BaseClientT]":
+        if self.__lti is None:
+            import codegrade._api.lti as m
+
+            self.__lti = m.LTIService(self)
+        return self.__lti
+
+    @property
+    def tenant(self: _BaseClientT) -> "_TenantService[_BaseClientT]":
+        if self.__tenant is None:
+            import codegrade._api.tenant as m
+
+            self.__tenant = m.TenantService(self)
+        return self.__tenant
+
+    @property
+    def submission(self: _BaseClientT) -> "_SubmissionService[_BaseClientT]":
+        if self.__submission is None:
+            import codegrade._api.submission as m
+
+            self.__submission = m.SubmissionService(self)
+        return self.__submission
+
+    @property
+    def file(self: _BaseClientT) -> "_FileService[_BaseClientT]":
+        if self.__file is None:
+            import codegrade._api.file as m
+
+            self.__file = m.FileService(self)
+        return self.__file
+
+    @property
+    def login_link(self: _BaseClientT) -> "_LoginLinkService[_BaseClientT]":
+        if self.__login_link is None:
+            import codegrade._api.login_link as m
+
+            self.__login_link = m.LoginLinkService(self)
+        return self.__login_link
+
     @property
     def user_setting(
         self: _BaseClientT,
@@ -134,12 +225,12 @@ class _BaseClient:
         return self.__user_setting
 
     @property
-    def lti(self: _BaseClientT) -> "_LTIService[_BaseClientT]":
-        if self.__lti is None:
-            import codegrade._api.lti as m
+    def comment(self: _BaseClientT) -> "_CommentService[_BaseClientT]":
+        if self.__comment is None:
+            import codegrade._api.comment as m
 
-            self.__lti = m.LTIService(self)
-        return self.__lti
+            self.__comment = m.CommentService(self)
+        return self.__comment
 
     @property
     def site_settings(
@@ -152,52 +243,12 @@ class _BaseClient:
         return self.__site_settings
 
     @property
-    def assignment(self: _BaseClientT) -> "_AssignmentService[_BaseClientT]":
-        if self.__assignment is None:
-            import codegrade._api.assignment as m
+    def snippet(self: _BaseClientT) -> "_SnippetService[_BaseClientT]":
+        if self.__snippet is None:
+            import codegrade._api.snippet as m
 
-            self.__assignment = m.AssignmentService(self)
-        return self.__assignment
-
-    @property
-    def auto_test(self: _BaseClientT) -> "_AutoTestService[_BaseClientT]":
-        if self.__auto_test is None:
-            import codegrade._api.auto_test as m
-
-            self.__auto_test = m.AutoTestService(self)
-        return self.__auto_test
-
-    @property
-    def course(self: _BaseClientT) -> "_CourseService[_BaseClientT]":
-        if self.__course is None:
-            import codegrade._api.course as m
-
-            self.__course = m.CourseService(self)
-        return self.__course
-
-    @property
-    def tenant(self: _BaseClientT) -> "_TenantService[_BaseClientT]":
-        if self.__tenant is None:
-            import codegrade._api.tenant as m
-
-            self.__tenant = m.TenantService(self)
-        return self.__tenant
-
-    @property
-    def about(self: _BaseClientT) -> "_AboutService[_BaseClientT]":
-        if self.__about is None:
-            import codegrade._api.about as m
-
-            self.__about = m.AboutService(self)
-        return self.__about
-
-    @property
-    def user(self: _BaseClientT) -> "_UserService[_BaseClientT]":
-        if self.__user is None:
-            import codegrade._api.user as m
-
-            self.__user = m.UserService(self)
-        return self.__user
+            self.__snippet = m.SnippetService(self)
+        return self.__snippet
 
     @property
     def task_result(self: _BaseClientT) -> "_TaskResultService[_BaseClientT]":
@@ -207,46 +258,6 @@ class _BaseClient:
             self.__task_result = m.TaskResultService(self)
         return self.__task_result
 
-    @property
-    def comment(self: _BaseClientT) -> "_CommentService[_BaseClientT]":
-        if self.__comment is None:
-            import codegrade._api.comment as m
-
-            self.__comment = m.CommentService(self)
-        return self.__comment
-
-    @property
-    def submission(self: _BaseClientT) -> "_SubmissionService[_BaseClientT]":
-        if self.__submission is None:
-            import codegrade._api.submission as m
-
-            self.__submission = m.SubmissionService(self)
-        return self.__submission
-
-    @property
-    def group(self: _BaseClientT) -> "_GroupService[_BaseClientT]":
-        if self.__group is None:
-            import codegrade._api.group as m
-
-            self.__group = m.GroupService(self)
-        return self.__group
-
-    @property
-    def login_link(self: _BaseClientT) -> "_LoginLinkService[_BaseClientT]":
-        if self.__login_link is None:
-            import codegrade._api.login_link as m
-
-            self.__login_link = m.LoginLinkService(self)
-        return self.__login_link
-
-    @property
-    def file(self: _BaseClientT) -> "_FileService[_BaseClientT]":
-        if self.__file is None:
-            import codegrade._api.file as m
-
-            self.__file = m.FileService(self)
-        return self.__file
-
 
 class Client(_BaseClient):
     """A class used to do unauthenticated requests to CodeGrade"""
