@@ -27,9 +27,12 @@ from .auto_test_quality_comment import AutoTestQualityComment
 from .auto_test_result import AutoTestResult
 from .auto_test_result_state import AutoTestResultState
 from .auto_test_run import AutoTestRun
+from .auto_test_runner import AutoTestRunner
+from .auto_test_runner_state import AutoTestRunnerState
 from .auto_test_set import AutoTestSet
 from .auto_test_step_base import AutoTestStepBase
 from .auto_test_step_base_input_as_json import AutoTestStepBaseInputAsJSON
+from .auto_test_step_log_base import AutoTestStepLogBase
 from .auto_test_step_result import AutoTestStepResult
 from .auto_test_step_result_state import AutoTestStepResultState
 from .auto_test_suite import AutoTestSuite
@@ -61,6 +64,8 @@ from .create_auto_test_data import CreateAutoTestData
 from .create_course_data import CreateCourseData
 from .create_lti_data import CreateLTIData
 from .create_tenant_data import CreateTenantData
+from .custom_output_log import CustomOutputLog
+from .custom_output_log_base import CustomOutputLogBase
 from .email_notification_types import EmailNotificationTypes
 from .email_users_course_data import EmailUsersCourseData
 from .extended_auto_test_result import ExtendedAutoTestResult
@@ -81,15 +86,21 @@ from .finalized_lti1p1_provider import FinalizedLTI1p1Provider
 from .finalized_lti1p3_provider import FinalizedLTI1p3Provider
 from .fixture_like import FixtureLike
 from .frontend_site_settings import FrontendSiteSettings
+from .global_perm_map import GlobalPermMap
 from .grade_history import GradeHistory
 from .grade_origin import GradeOrigin
 from .group import Group
 from .group_set import GroupSet
 from .health_information import HealthInformation
+from .io_test_log import IOTestLog
+from .io_test_step_log import IOTestStepLog
+from .io_test_step_log_base import IOTestStepLogBase
 from .job import Job
 from .json_create_auto_test import JsonCreateAutoTest
 from .json_create_tenant import JsonCreateTenant
 from .json_patch_auto_test import JsonPatchAutoTest
+from .junit_test_log import JunitTestLog
+from .junit_test_log_base import JunitTestLogBase
 from .legacy_features import LegacyFeatures
 from .line_range import LineRange
 from .linter_comment import LinterComment
@@ -117,6 +128,7 @@ from .patch_tenant_data import PatchTenantData
 from .patch_ui_preference_user_setting_data import (
     PatchUiPreferenceUserSettingData,
 )
+from .patch_user_data import PatchUserData
 from .plagiarism_run import PlagiarismRun
 from .plagiarism_run_plagiarism_assignment_as_json import (
     PlagiarismRunPlagiarismAssignmentAsJSON,
@@ -128,11 +140,18 @@ from .plagiarism_state import PlagiarismState
 from .put_enroll_link_course_data import PutEnrollLinkCourseData
 from .put_rubric_assignment_data import PutRubricAssignmentData
 from .quality_comment_severity import QualityCommentSeverity
+from .quality_test_log import QualityTestLog
+from .quality_test_log_base import QualityTestLogBase
 from .register_user_data import RegisterUserData
 from .release_info import ReleaseInfo
 from .result_data_get_auto_test_get import ResultDataGetAutoTestGet
 from .result_data_get_task_result_get_all import ResultDataGetTaskResultGetAll
+from .result_data_get_user_setting_get_all_ui_preferences import (
+    ResultDataGetUserSettingGetAllUiPreferences,
+)
+from .result_data_post_login_link_login import ResultDataPostLoginLinkLogin
 from .result_data_post_user_login import ResultDataPostUserLogin
+from .result_data_post_user_register import ResultDataPostUserRegister
 from .rubric_description_type import RubricDescriptionType
 from .rubric_item import RubricItem
 from .rubric_item_input_as_json import RubricItemInputAsJSON
@@ -140,7 +159,9 @@ from .rubric_lock_reason import RubricLockReason
 from .rubric_row_base import RubricRowBase
 from .rubric_row_base_input_as_json import RubricRowBaseInputAsJSON
 from .rubric_row_base_input_base_as_json import RubricRowBaseInputBaseAsJSON
+from .run_program_log import RunProgramLog
 from .site_setting_input import SiteSettingInput
+from .snippet import Snippet
 from .submission_validator_input_data import SubmissionValidatorInputData
 from .task_result_state import TaskResultState
 from .tenant import Tenant
@@ -153,7 +174,6 @@ from .update_suite_auto_test_data import UpdateSuiteAutoTestData
 from .user import User
 from .user_course import UserCourse
 from .user_input import UserInput
-from .user_login_response import UserLoginResponse
 from .user_without_group import UserWithoutGroup
 from .webhook_base import WebhookBase
 from .work import Work
