@@ -37,7 +37,7 @@ class AbstractRole:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["id"] = to_dict(self.id)
         res["name"] = to_dict(self.name)
         return res
