@@ -342,7 +342,7 @@ class Assignment:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["id"] = to_dict(self.id)
         res["state"] = to_dict(self.state)
         res["description"] = to_dict(self.description)
