@@ -78,7 +78,7 @@ class AutoTestResult:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["id"] = to_dict(self.id)
         res["created_at"] = to_dict(self.created_at)
         res["started_at"] = to_dict(self.started_at)
