@@ -45,7 +45,7 @@ class BaseLTI1p1Provider(BaseLTIProvider):
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["version"] = to_dict(self.version)
         res["supports_lock_date"] = to_dict(self.supports_lock_date)
         res["id"] = to_dict(self.id)
