@@ -50,7 +50,7 @@ class BaseLTI1p3Provider(BaseLTIProvider):
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["capabilities"] = to_dict(self.capabilities)
         res["version"] = to_dict(self.version)
         res["iss"] = to_dict(self.iss)
