@@ -30,7 +30,7 @@ class BaseReleaseInfo:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["commit"] = to_dict(self.commit)
         return res
 
