@@ -33,7 +33,7 @@ class CopyAutoTestData:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["assignment_id"] = to_dict(self.assignment_id)
         return res
 
