@@ -33,7 +33,7 @@ class CopyRubricAssignmentData:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["old_assignment_id"] = to_dict(self.old_assignment_id)
         return res
 
