@@ -102,7 +102,7 @@ class Course:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["id"] = to_dict(self.id)
         res["name"] = to_dict(self.name)
         res["created_at"] = to_dict(self.created_at)
