@@ -54,7 +54,7 @@ class CreateLTIData_1:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["tenant_id"] = to_dict(self.tenant_id)
         res["lms"] = to_dict(self.lms)
         res["lti_version"] = to_dict(self.lti_version)
@@ -119,7 +119,7 @@ class CreateLTIData_1_2:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["tenant_id"] = to_dict(self.tenant_id)
         res["iss"] = to_dict(self.iss)
         res["lms"] = to_dict(self.lms)
