@@ -51,7 +51,7 @@ class ExtendedCourse(Course):
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["assignments"] = to_dict(self.assignments)
         res["group_sets"] = to_dict(self.group_sets)
         res["snippets"] = to_dict(self.snippets)
