@@ -58,7 +58,7 @@ class FeedbackWithoutReplies(FeedbackBase):
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["user"] = to_dict(self.user)
         res["authors"] = to_dict(self.authors)
         res["general"] = to_dict(self.general)
