@@ -37,7 +37,7 @@ class FinalizedLTI1p1Provider(BaseLTI1p1Provider):
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["finalized"] = to_dict(self.finalized)
         res["version"] = to_dict(self.version)
         res["supports_lock_date"] = to_dict(self.supports_lock_date)
