@@ -103,6 +103,8 @@ class FrontendSiteSettings:
     email_students_enabled: "bool"
     #: Should peer feedback be enabled.
     peer_feedback_enabled: "bool"
+    #: Should AT image caching be enabled.
+    at_image_caching_enabled: "bool"
 
     raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
 
@@ -332,11 +334,16 @@ class FrontendSiteSettings:
                 rqa.SimpleValue.bool,
                 doc="Should peer feedback be enabled.",
             ),
+            rqa.RequiredArgument(
+                "AT_IMAGE_CACHING_ENABLED",
+                rqa.SimpleValue.bool,
+                doc="Should AT image caching be enabled.",
+            ),
         ).use_readable_describe(True)
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["AUTO_TEST_MAX_TIME_COMMAND"] = to_dict(
             self.auto_test_max_time_command
         )
@@ -398,6 +405,9 @@ class FrontendSiteSettings:
         res["RENDER_HTML_ENABLED"] = to_dict(self.render_html_enabled)
         res["EMAIL_STUDENTS_ENABLED"] = to_dict(self.email_students_enabled)
         res["PEER_FEEDBACK_ENABLED"] = to_dict(self.peer_feedback_enabled)
+        res["AT_IMAGE_CACHING_ENABLED"] = to_dict(
+            self.at_image_caching_enabled
+        )
         return res
 
     @classmethod
@@ -438,6 +448,7 @@ class FrontendSiteSettings:
             render_html_enabled=parsed.RENDER_HTML_ENABLED,
             email_students_enabled=parsed.EMAIL_STUDENTS_ENABLED,
             peer_feedback_enabled=parsed.PEER_FEEDBACK_ENABLED,
+            at_image_caching_enabled=parsed.AT_IMAGE_CACHING_ENABLED,
         )
         res.raw_data = d
         return res
