@@ -65,7 +65,7 @@ class HealthInformation:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["application"] = to_dict(self.application)
         res["database"] = to_dict(self.database)
         res["uploads"] = to_dict(self.uploads)
