@@ -37,7 +37,7 @@ class LineRange:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["start"] = to_dict(self.start)
         res["end"] = to_dict(self.end)
         return res
