@@ -185,7 +185,7 @@ class LMSCapabilities:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["lms"] = to_dict(self.lms)
         res["set_deadline"] = to_dict(self.set_deadline)
         res["set_lock_date"] = to_dict(self.set_lock_date)
