@@ -68,7 +68,7 @@ class NonFinalizedLTI1p1Provider(BaseLTI1p1Provider):
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["finalized"] = to_dict(self.finalized)
         res["edit_secret"] = to_dict(self.edit_secret)
         res["lms_consumer_key"] = to_dict(self.lms_consumer_key)
