@@ -247,7 +247,7 @@ class PatchAssignmentData:
         self.done_email = maybe_from_nullable(self.done_email)
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         if self.state.is_just:
             res["state"] = to_dict(self.state.value)
         if self.name.is_just:
