@@ -30,7 +30,7 @@ class PatchGraderSubmissionData:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["user_id"] = to_dict(self.user_id)
         return res
 
