@@ -32,7 +32,7 @@ class PatchSiteSettingsData:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["updates"] = to_dict(self.updates)
         return res
 
