@@ -48,7 +48,7 @@ class AutoTestMaxTimeCommandSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -94,7 +94,7 @@ class AutoTestHeartbeatIntervalSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -138,7 +138,7 @@ class AutoTestHeartbeatMaxMissedSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -182,7 +182,7 @@ class AutoTestMaxJobsPerRunnerSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -226,7 +226,7 @@ class AutoTestMaxConcurrentBatchRunsSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -270,7 +270,7 @@ class AutoTestIoTestMessageSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -314,7 +314,7 @@ class AutoTestIoTestSubMessageSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -358,7 +358,7 @@ class AutoTestRunProgramMessageSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -402,7 +402,7 @@ class AutoTestCapturePointsMessageSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -446,7 +446,7 @@ class AutoTestCheckpointMessageSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -490,7 +490,7 @@ class AutoTestUnitTestMessageSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -534,7 +534,7 @@ class AutoTestCodeQualityMessageSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -580,7 +580,7 @@ class ExamLoginMaxLengthSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -628,7 +628,7 @@ class LoginTokenBeforeTimeSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -672,7 +672,7 @@ class MinPasswordScoreSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -718,7 +718,7 @@ class ResetTokenTimeSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -764,7 +764,7 @@ class SettingTokenTimeSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -808,7 +808,7 @@ class SiteEmailSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -852,7 +852,7 @@ class MaxNumberOfFilesSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -898,7 +898,7 @@ class MaxLargeUploadSizeSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -944,7 +944,7 @@ class MaxNormalUploadSizeSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -990,7 +990,7 @@ class MaxFileSizeSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -1036,7 +1036,7 @@ class JwtAccessTokenExpiresSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -1080,7 +1080,7 @@ class MaxLinesSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -1126,7 +1126,7 @@ class NotificationPollTimeSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -1172,7 +1172,7 @@ class ReleaseMessageMaxTimeSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -1216,7 +1216,7 @@ class MaxPlagiarismMatchesSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -1262,7 +1262,7 @@ class AutoTestMaxGlobalSetupTimeSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -1308,7 +1308,7 @@ class AutoTestMaxPerStudentSetupTimeSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -1354,7 +1354,7 @@ class ServerTimeDiffToleranceSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -1398,7 +1398,7 @@ class BlackboardZipUploadEnabledSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -1442,7 +1442,7 @@ class RubricsEnabledSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -1486,7 +1486,7 @@ class AutomaticLtiRoleEnabledSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -1530,7 +1530,7 @@ class LtiEnabledSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -1574,7 +1574,7 @@ class LintersEnabledSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -1618,7 +1618,7 @@ class IncrementalRubricSubmissionEnabledSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -1663,7 +1663,7 @@ class RegisterEnabledSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -1707,7 +1707,7 @@ class GroupsEnabledSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -1751,7 +1751,7 @@ class AutoTestEnabledSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -1795,7 +1795,7 @@ class CourseRegisterEnabledSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -1839,7 +1839,7 @@ class RenderHtmlEnabledSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -1883,7 +1883,7 @@ class EmailStudentsEnabledSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -1927,7 +1927,7 @@ class PeerFeedbackEnabledSetting:
     )
 
     def to_dict(self) -> Dict[str, Any]:
-        res = {}
+        res: Dict[str, Any] = {}
         res["name"] = to_dict(self.name)
         res["value"] = to_dict(self.value)
         return res
@@ -1946,6 +1946,50 @@ class PeerFeedbackEnabledSetting:
         return res
 
 
+@dataclass
+class AtImageCachingEnabledSetting:
+    """"""
+
+    name: "Literal['AT_IMAGE_CACHING_ENABLED']"
+    value: "Optional[bool]"
+
+    raw_data: Optional[Dict[str, Any]] = field(init=False, repr=False)
+
+    data_parser: ClassVar = rqa.Lazy(
+        lambda: rqa.FixedMapping(
+            rqa.RequiredArgument(
+                "name",
+                rqa.StringEnum("AT_IMAGE_CACHING_ENABLED"),
+                doc="",
+            ),
+            rqa.RequiredArgument(
+                "value",
+                rqa.Nullable(rqa.SimpleValue.bool),
+                doc="",
+            ),
+        ).use_readable_describe(True)
+    )
+
+    def to_dict(self) -> Dict[str, Any]:
+        res: Dict[str, Any] = {}
+        res["name"] = to_dict(self.name)
+        res["value"] = to_dict(self.value)
+        return res
+
+    @classmethod
+    def from_dict(
+        cls: Type["AtImageCachingEnabledSetting"], d: Dict[str, Any]
+    ) -> "AtImageCachingEnabledSetting":
+        parsed = cls.data_parser.try_parse(d)
+
+        res = cls(
+            name=parsed.name,
+            value=parsed.value,
+        )
+        res.raw_data = d
+        return res
+
+
 SiteSettingInput = Union[
     AutoTestMaxTimeCommandSetting,
     AutoTestHeartbeatIntervalSetting,
@@ -1990,6 +2034,7 @@ SiteSettingInput = Union[
     RenderHtmlEnabledSetting,
     EmailStudentsEnabledSetting,
     PeerFeedbackEnabledSetting,
+    AtImageCachingEnabledSetting,
 ]
 SiteSettingInputParser = rqa.Lazy(
     lambda: make_union(
@@ -2036,5 +2081,6 @@ SiteSettingInputParser = rqa.Lazy(
         ParserFor.make(RenderHtmlEnabledSetting),
         ParserFor.make(EmailStudentsEnabledSetting),
         ParserFor.make(PeerFeedbackEnabledSetting),
+        ParserFor.make(AtImageCachingEnabledSetting),
     ),
 )
